.. Copyright 2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.holder.holder
------------------------------

.. sidebar:: Behind the scenes

   This module uses `Holder.js <http://imsky.github.io/holder/>`_ to
   provide its functionality.

.. automodule:: reahl.web.holder.holder



PlaceholderImage
""""""""""""""""

.. sidebar:: Examples in this section

   - features.carousel

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. autoclass:: PlaceholderImage
   :members:

PredefinedTheme
"""""""""""""""

.. autoclass:: PredefinedTheme
   :members:

CustomTheme
"""""""""""

.. autoclass:: CustomTheme
   :members:

